# Standard Block

::: linax.blocks.standard.StandardBlockConfig
    options:
        members:
            - build

---

::: linax.blocks.standard.StandardBlock
    options:
        members:
            - __init__
            - __call__
